searchNodes=[{"doc":"CandleClock manages timers that persist even across restarts. Core concepts Timer A timer is a function call that will happen at some point in the future. It always contains an MFA and either a duration, an interval or a crontab expression. MFA An MFA is a tuple with 3 elements: the module, the function and the arguments to pass to the function. The 3 elements of the tuple are the same as the 3 arguments you'd pass to Kernel.apply/3 . Crontab A crontab expression can be used when you want the timer to trigger at regular dates or times, such as Every monday at 12 AM: 0 12 * * 1 Every 5 minutes: */5 * * * * Every hour: 0 * * * * Every day at 5 PM: 0 17 * * * Timers with crontabs can be given an additional time zone so 0 17 * * * for Europe/Berlin is 16:00 UTC during winter time but 15:00 UTC during summer time. Startup behaviour At startup, all timers that have an expired_at date in the past will be executed. When planning the next execution time of a single timer, it will take the last execution time as the basis. However, that might lead to a timer being called multiple times directly after a long downtime. For that reason, if :skip_if_offline is true, interval and cron timers will instead be planned to the next time it would've happened as if the earlier intervals would've been triggered as well, but they won't be called more than once at startup. :skip_if_offline is enabled by default. Duration and intervals All durations and intervals are integers in the unit millisecond. Common options These are the common options that can be passed to call_after/3 , call_interval/4 and call_crontab/4 : :name (string) A name that makes this timer unique. Unique timers will be replaced when a new timer with the same name is created. That way, a defer can be implemented simply by always giving the same name. :if_not_exists (bool, default: false ) If set to true, will not create the timer if one already exists with that name. Requires a name to be set. :skip_if_offline (bool, default: true ) If set to false, interval and cron timers behave differently after a long downtime of the system. See also: Startup behaviour :max_calls (int, default: nil or 1 for duration timers) Controls the maximum amount this timer can be called before it is cancelled. Not supported in duration timers started with call_after/3 .","ref":"CandleClock.html","title":"CandleClock","type":"module"},{"doc":"Creates a timer that is executed after the duration in milliseconds. Returns the timer in an ok-tuple if successful.","ref":"CandleClock.html#call_after/3","title":"CandleClock.call_after/3","type":"function"},{"doc":"","ref":"CandleClock.html#call_at/3","title":"CandleClock.call_at/3","type":"function"},{"doc":"Creates a timer that is executed according to the given crontab schema. Returns the timer in an ok-tuple if successful.","ref":"CandleClock.html#call_crontab/4","title":"CandleClock.call_crontab/4","type":"function"},{"doc":"Creates a timer that is executed every interval ms. Additionally, the duration until the first trigger can be passed with the duration argument. Returns the timer in an ok-tuple if successful.","ref":"CandleClock.html#call_interval/4","title":"CandleClock.call_interval/4","type":"function"},{"doc":"Cancels all timers that call the given module and function. Returns {:ok, amount} if successful, where amount is the number of timers that were cancelled.","ref":"CandleClock.html#cancel_all/2","title":"CandleClock.cancel_all/2","type":"function"},{"doc":"Cancels a timer by its ID. Returns {:ok, 1} if the ID matched.","ref":"CandleClock.html#cancel_by_id/1","title":"CandleClock.cancel_by_id/1","type":"function"},{"doc":"Cancels the timer with the given name. Returns {:ok, 1} if a timer with that name was found.","ref":"CandleClock.html#cancel_by_name/1","title":"CandleClock.cancel_by_name/1","type":"function"},{"doc":"Creates a list of timers at once (using insert_all). Schemas for the different timer types: For all timer types %{ module : module ( ) , function : atom ( ) , arguments : list ( ) , inserted_at : DateTime . t ( ) , updated_at : DateTime . t ( ) } as well as any custom fields defined in the candle clock timer schema . Duration %{ duration : non_neg_integer ( ) , # milliseconds max_calls : 1 } Interval %{ duration : non_neg_integer ( ) , # milliseconds interval : non_neg_integer ( ) , # milliseconds max_calls : nil | non_neg_integer ( ) # nil for unlimited calls } Once, at a specific date and time %{ expires_at : DateTime . t ( ) , max_calls : 1 } Cron %{ crontab : Crontab.CronExpression . t ( ) , crontab_timezone : binary ( ) # &quot;Europe/Berlin&quot; for example. }","ref":"CandleClock.html#create_many/2","title":"CandleClock.create_many/2","type":"function"},{"doc":"Returns if a timer with the given id exists","ref":"CandleClock.html#id_exists?/1","title":"CandleClock.id_exists?/1","type":"function"},{"doc":"Returns if a timer with the given name exists","ref":"CandleClock.html#name_exists?/1","title":"CandleClock.name_exists?/1","type":"function"},{"doc":"Calculates the next expiry date for the given timer from the given date onwards. Returns {:ok, datetime} or an error-tuple","ref":"CandleClock.html#next_expiry/2","title":"CandleClock.next_expiry/2","type":"function"},{"doc":"","ref":"CandleClock.html#t:alarm_spec/0","title":"CandleClock.alarm_spec/0","type":"type"},{"doc":"","ref":"CandleClock.html#t:argument/0","title":"CandleClock.argument/0","type":"type"},{"doc":"","ref":"CandleClock.html#t:arguments/0","title":"CandleClock.arguments/0","type":"type"},{"doc":"","ref":"CandleClock.html#t:cron_timer_spec/0","title":"CandleClock.cron_timer_spec/0","type":"type"},{"doc":"","ref":"CandleClock.html#t:duration_timer_spec/0","title":"CandleClock.duration_timer_spec/0","type":"type"},{"doc":"","ref":"CandleClock.html#t:interval/0","title":"CandleClock.interval/0","type":"type"},{"doc":"","ref":"CandleClock.html#t:interval_timer_spec/0","title":"CandleClock.interval_timer_spec/0","type":"type"},{"doc":"","ref":"CandleClock.html#t:mf_args/0","title":"CandleClock.mf_args/0","type":"type"},{"doc":"","ref":"CandleClock.html#t:timer_spec/0","title":"CandleClock.timer_spec/0","type":"type"},{"doc":"","ref":"CandleClock.ErrorLogger.html","title":"CandleClock.ErrorLogger","type":"module"},{"doc":"Formats the given error using Exception.format/3 . Adds the current stack trace, if available.","ref":"CandleClock.ErrorLogger.html#format_error/2","title":"CandleClock.ErrorLogger.format_error/2","type":"macro"},{"doc":"Returns if the environment is within a catch or rescue clause. Use it like this in a macro: defmacro maybe_get_stacktrace ( ) do if in_catch? ( __CALLER__ ) do quote do __STACKTRACE__ end else quote do [ ] end end end","ref":"CandleClock.ErrorLogger.html#in_catch?/1","title":"CandleClock.ErrorLogger.in_catch?/1","type":"function"},{"doc":"Formats and logs the given error using Exception.format/3 and Logger.error/1 . Depending on from where this macro is called, it will also include the stacktrace that was recorded with the error in the log message. error can be anything, special formatting will be done for certain Erlang error atoms or tuples, as well as Elixir exceptions. log_level (default :error ) can be overwritten to log in a different level metadata optional metadata passed into the Logger","ref":"CandleClock.ErrorLogger.html#log_error/3","title":"CandleClock.ErrorLogger.log_error/3","type":"macro"},{"doc":"Formats and logs the given error of the given kind with an optional preceding message .","ref":"CandleClock.ErrorLogger.html#log_error_raw/5","title":"CandleClock.ErrorLogger.log_error_raw/5","type":"macro"},{"doc":"Like log_error/3 , but is used to log caught exits. When the pid is given, it will pass {:EXIT, pid} instead of :exit to Exception.format/3 .","ref":"CandleClock.ErrorLogger.html#log_exit/4","title":"CandleClock.ErrorLogger.log_exit/4","type":"macro"},{"doc":"Logs a formatted error with an optional preceding message.","ref":"CandleClock.ErrorLogger.html#log_formatted/4","title":"CandleClock.ErrorLogger.log_formatted/4","type":"function"},{"doc":"Like log_error/3 , but also puts the given message before the formatted error.","ref":"CandleClock.ErrorLogger.html#log_message_and_error/4","title":"CandleClock.ErrorLogger.log_message_and_error/4","type":"macro"},{"doc":"","ref":"CandleClock.ErrorLogger.html#t:error/0","title":"CandleClock.ErrorLogger.error/0","type":"type"},{"doc":"","ref":"CandleClock.ErrorLogger.html#t:kind/0","title":"CandleClock.ErrorLogger.kind/0","type":"type"},{"doc":"","ref":"CandleClock.ErrorLogger.html#t:message/0","title":"CandleClock.ErrorLogger.message/0","type":"type"},{"doc":"Waits until timers expire and calls them. Add this module to your supervisor-tree once.","ref":"CandleClock.Worker.html","title":"CandleClock.Worker","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"CandleClock.Worker.html#child_spec/1","title":"CandleClock.Worker.child_spec/1","type":"function"},{"doc":"","ref":"CandleClock.Worker.html#next_expiry_query/0","title":"CandleClock.Worker.next_expiry_query/0","type":"function"},{"doc":"Refreshes the internal timer until the next invocation for the current node.","ref":"CandleClock.Worker.html#refresh/0","title":"CandleClock.Worker.refresh/0","type":"function"},{"doc":"","ref":"CandleClock.Worker.html#set_next_expiry/1","title":"CandleClock.Worker.set_next_expiry/1","type":"function"},{"doc":"Starts the CandleClock worker.","ref":"CandleClock.Worker.html#start_link/0","title":"CandleClock.Worker.start_link/0","type":"function"},{"doc":"","ref":"CandleClock.Worker.html#start_link/1","title":"CandleClock.Worker.start_link/1","type":"function"},{"doc":"","ref":"Mix.Tasks.CandleClock.Gen.Migrations.html","title":"Mix.Tasks.CandleClock.Gen.Migrations","type":"task"},{"doc":"","ref":"Mix.Tasks.CandleClock.Gen.Migrations.html#create_migrations/2","title":"Mix.Tasks.CandleClock.Gen.Migrations.create_migrations/2","type":"function"},{"doc":"","ref":"Mix.Tasks.CandleClock.Gen.Migrations.html#render_migration_20200120140538_create_candle_clock_timer_table/1","title":"Mix.Tasks.CandleClock.Gen.Migrations.render_migration_20200120140538_create_candle_clock_timer_table/1","type":"function"},{"doc":"Callback implementation for Mix.Task.run/1 .","ref":"Mix.Tasks.CandleClock.Gen.Migrations.html#run/1","title":"Mix.Tasks.CandleClock.Gen.Migrations.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.CandleClock.Gen.Schema.html","title":"Mix.Tasks.CandleClock.Gen.Schema","type":"task"},{"doc":"","ref":"Mix.Tasks.CandleClock.Gen.Schema.html#run/1","title":"Mix.Tasks.CandleClock.Gen.Schema.run/1","type":"function"}]